@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,11 +23,9 @@
 #include "sendlater_export.h"
 #include <KSharedConfig>
 
-namespace SendLater
-{
+namespace SendLater {
 class SendLaterInfo;
-namespace SendLaterUtil
-{
+namespace SendLaterUtil {
 QDateTime updateRecurence(SendLater::SendLaterInfo *info, QDateTime dateTime);
 }
 }
